Security Advisories (6)
CVE-2016-1238 (2016-08-02)

Imager would search the default current directory entry in @INC when searching for file format support modules.

CVE-2008-1928 (2008-04-24)

Buffer overflow in Imager 0.42 through 0.63 allows attackers to cause a denial of service (crash) via an image based fill in which the number of input channels is different from the number of output channels.

CPANSA-Imager-2014-01 (2014-01-03)

When drawing on an image with an alpha channel where the source minimum is greater than zero, Imager would read from beyond the end of a malloc() allocated buffer. In rare circumstances this could lead to some of the source image not being written to the target image, or possibly to a segmentation fault.

CVE-2007-2459 (2007-05-02)

Heap-based buffer overflow in the BMP reader (bmp.c) in Imager perl module (libimager-perl) 0.45 through 0.56 allows remote attackers to cause a denial of service (application crash) and possibly execute arbitrary code via crafted 8-bit/pixel compressed BMP files.

CVE-2006-0053 (2006-04-10)

Imager (libimager-perl) before 0.50 allows user-assisted attackers to cause a denial of service (segmentation fault) by writing a 2- or 4-channel JPEG image (or a 2-channel TGA image) to a scalar, which triggers a NULL pointer dereference.

CVE-2024-53901 (2024-11-17)

"invalid next size" backtrace on use of trim on certain images

NAME

Imager::Font::Type1 - low-level functions for Type1 fonts

DESCRIPTION

Imager::Font creates a Imager::Font::Type1 object when asked to create a font object based on a .pfb file.

See Imager::Font to see how to use this type.

This class provides low-level functions that require the caller to perform data validation

By default Imager no longer creates the t1lib.log log file. You can re-enable that by calling Imager::init() with the t1log option:

Imager::init(t1log=>1);

Currently specific to Imager::Font::Type1, you can use the following flags when drawing text or calculating a bounding box:

underline

Draw the text with an underline.

overline

Draw the text with an overline.

strikethrough

Draw the text with a strikethrough.

Obviously, if you're calculating the bounding box the size of the line is included in the box, and the line isn't drawn :)

AUTHOR

Addi, Tony